==> Pedixplorer_1.0.0.tar.gz: Pedixplorer/tests/testthat/_snaps/align.md <==
# test auto_hint works

    Code
      plist
    Output
      $n
      [1]  4 17 21 14
      
      $nid
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]   35   36   42   43    0    0    0    0    0     0     0     0     0     0
      [2,]    1    2    3    4   37   38   44   45   46    47    48    50    49     5
      [3,]    9   10   11   12   14   39   40   41   51    52    53    54    55    14
      [4,]   21   22   23   24   27   28   25   26   29    30    31    32    33    34
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     6     7     8     0     0     0     0
      [3,]    15    12    18    17    16    19    20
      [4,]     0     0     0     0     0     0     0
      
      $pos
                    [,1]     [,2]     [,3]      [,4]      [,5]      [,6]      [,7]
      [1,]  3.803847e+00 4.803847 9.576274 10.576274  0.000000  0.000000  0.000000
      [2,] -6.622646e-13 1.000000 2.803847  3.803847  4.803847  5.803847  6.876275
      [3,]  8.609109e-17 1.000000 2.000000  3.000000  4.000000  5.000000  6.000000
      [4,] -1.645370e-15 1.000000 2.000000  3.000000 11.010000 12.010000 13.010000
                [,8]      [,9]     [,10]    [,11]    [,12]    [,13] [,14] [,15] [,16]
      [1,]  0.000000  0.000000  0.000000  0.00000  0.00000  0.00000  0.00  0.00  0.00
      [2,]  7.876275  8.876275  9.876275 10.87627 11.87627 12.87627 16.25 17.25 19.01
      [3,]  7.000000  8.000000  9.000000 10.00000 11.00000 12.00000 13.00 14.00 15.00
      [4,] 14.010000 15.010000 16.010000 17.01000 18.01000 19.01000 20.01  0.00  0.00
           [,17] [,18] [,19] [,20] [,21]
      [1,]  0.00     0     0     0     0
      [2,] 20.01     0     0     0     0
      [3,] 16.00    17    18    19    20
      [4,]  0.00     0     0     0     0
      
      $fam
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
      [2,]    0    0    1    0    0    1    0    3    3     3     3     0     3     0
      [3,]    1    3    3    3    3    5    5    5    7     7    12    12    12     0
      [4,]    1    1    1    1   14   14   16   16   18    20    20    20    20    20
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     0     0     0     0     0     0
      [3,]    14     0    14     0    14    14    16
      [4,]     0     0     0     0     0     0     0
      
      $spouse
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    1    0    1    0    0    0    0    0    0     0     0     0     0     0
      [2,]    1    0    1    0    1    0    1    0    0     0     0     1     0     1
      [3,]    1    0    0    0    0    0    0    0    0     0     0     0     0     1
      [4,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     1     0     0     0     0     0
      [3,]     0     1     0     1     0     1     0
      [4,]     0     0     0     0     0     0     0
      

# besthint works

    Code
      plist
    Output
      $n
      [1]  4 17 21 14
      
      $nid
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]   35   36   42   43    0    0    0    0    0     0     0     0     0     0
      [2,]    7    8    5    6    3    4   37   38    1     2    44    45    46    47
      [3,]   20   19   17   16   15   18   12   15   14    11    10    39    40    41
      [4,]   30   31   32   33   34   29   25   26   27    28    21    22    23    24
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]    48    50    49     0     0     0     0
      [3,]    10     9    51    52    53    54    55
      [4,]     0     0     0     0     0     0     0
      
      $pos
                   [,1]  [,2]  [,3]  [,4] [,5] [,6]  [,7]  [,8]  [,9] [,10] [,11]
      [1,] 9.010000e+00 10.01 16.71 17.71 0.00 0.00  0.00  0.00  0.00  0.00  0.00
      [2,] 1.855743e-15  1.00  2.76  3.76 8.01 9.01 10.01 11.01 12.01 13.01 14.01
      [3,] 1.000000e-02  1.01  2.01  3.01 4.01 5.01  6.01  7.01  8.01  9.01 10.01
      [4,] 2.880160e-14  1.00  2.00  3.00 4.00 5.00  6.00  7.00  8.00  9.00 13.01
           [,12] [,13] [,14] [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      [2,] 15.01 16.01 17.01 18.01 19.01 20.01  0.00  0.00  0.00  0.00
      [3,] 11.01 12.01 13.01 14.01 15.01 16.01 17.01 18.01 19.01 20.01
      [4,] 14.01 15.01 16.01  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      
      $fam
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
      [2,]    0    0    0    0    1    0    0    1    0     0     0     3     3     3
      [3,]    1    3    0    3    3    3    5    0    5     5     5     7     7     7
      [4,]    1    1    1    1    1    3    6    6    8     8    15    15    15    15
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     3     0     3     0     0     0     0
      [3,]     0     9    11    11    16    16    16
      [4,]     0     0     0     0     0     0     0
      
      $spouse
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    1    0    1    0    0    0    0    0    0     0     0     0     0     0
      [2,]    1    0    1    0    1    0    1    0    1     0     1     0     0     0
      [3,]    1    0    1    0    0    1    0    1    0     0     0     0     0     0
      [4,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     1     0     0     0     0     0
      [3,]     1     0     0     0     0     0     0
      [4,]     0     0     0     0     0     0     0

==> Pedixplorer_1.3.0.tar.gz: Pedixplorer/tests/testthat/_snaps/align.md <==
# test auto_hint works

    Code
      plist
    Output
      $n
      [1]  4 17 21 14
      
      $nid
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]   35   36   42   43    0    0    0    0    0     0     0     0     0     0
      [2,]    1    2    3    4   37   38   44   45   46    47    48    50    49     5
      [3,]    9   10   11   12   14   39   40   41   51    52    53    54    55    14
      [4,]   21   22   23   24   27   28   25   26   29    30    31    32    33    34
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     6     7     8     0     0     0     0
      [3,]    15    12    18    17    16    19    20
      [4,]     0     0     0     0     0     0     0
      
      $pos
           [,1] [,2] [,3]  [,4]  [,5]  [,6]  [,7]  [,8]  [,9] [,10] [,11] [,12] [,13]
      [1,]  3.8  4.8 9.58 10.58  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      [2,]  0.0  1.0 2.80  3.80  4.80  5.80  6.88  7.88  8.88  9.88 10.88 11.88 12.88
      [3,]  0.0  1.0 2.00  3.00  4.00  5.00  6.00  7.00  8.00  9.00 10.00 11.00 12.00
      [4,]  0.0  1.0 2.00  3.00 11.01 12.01 13.01 14.01 15.01 16.01 17.01 18.01 19.01
           [,14] [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]  0.00  0.00  0.00  0.00     0     0     0     0
      [2,] 16.25 17.25 19.01 20.01     0     0     0     0
      [3,] 13.00 14.00 15.00 16.00    17    18    19    20
      [4,] 20.01  0.00  0.00  0.00     0     0     0     0
      
      $fam
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
      [2,]    0    0    1    0    0    1    0    3    3     3     3     0     3     0
      [3,]    1    3    3    3    3    5    5    5    7     7    12    12    12     0
      [4,]    1    1    1    1   14   14   16   16   18    20    20    20    20    20
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     0     0     0     0     0     0
      [3,]    14     0    14     0    14    14    16
      [4,]     0     0     0     0     0     0     0
      
      $spouse
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    1    0    1    0    0    0    0    0    0     0     0     0     0     0
      [2,]    1    0    1    0    1    0    1    0    0     0     0     1     0     1
      [3,]    1    0    0    0    0    0    0    0    0     0     0     0     0     1
      [4,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     1     0     0     0     0     0
      [3,]     0     1     0     1     0     1     0
      [4,]     0     0     0     0     0     0     0
      

# besthint works

    Code
      plist
    Output
      $n
      [1]  4 17 21 14
      
      $nid
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]   35   36   42   43    0    0    0    0    0     0     0     0     0     0
      [2,]    7    8    5    6    3    4   37   38    1     2    44    45    46    47
      [3,]   20   19   17   16   15   18   12   15   14    11    10    39    40    41
      [4,]   30   31   32   33   34   29   25   26   27    28    21    22    23    24
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]    48    50    49     0     0     0     0
      [3,]    10     9    51    52    53    54    55
      [4,]     0     0     0     0     0     0     0
      
      $pos
           [,1]  [,2]  [,3]  [,4] [,5] [,6]  [,7]  [,8]  [,9] [,10] [,11] [,12] [,13]
      [1,] 9.01 10.01 16.71 17.71 0.00 0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      [2,] 0.00  1.00  2.76  3.76 8.01 9.01 10.01 11.01 12.01 13.01 14.01 15.01 16.01
      [3,] 0.01  1.01  2.01  3.01 4.01 5.01  6.01  7.01  8.01  9.01 10.01 11.01 12.01
      [4,] 0.00  1.00  2.00  3.00 4.00 5.00  6.00  7.00  8.00  9.00 13.01 14.01 15.01
           [,14] [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]  0.00  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      [2,] 17.01 18.01 19.01 20.01  0.00  0.00  0.00  0.00
      [3,] 13.01 14.01 15.01 16.01 17.01 18.01 19.01 20.01
      [4,] 16.01  0.00  0.00  0.00  0.00  0.00  0.00  0.00
      
      $fam
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
      [2,]    0    0    0    0    1    0    0    1    0     0     0     3     3     3
      [3,]    1    3    0    3    3    3    5    0    5     5     5     7     7     7
      [4,]    1    1    1    1    1    3    6    6    8     8    15    15    15    15
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     3     0     3     0     0     0     0
      [3,]     0     9    11    11    16    16    16
      [4,]     0     0     0     0     0     0     0
      
      $spouse
           [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12] [,13] [,14]
      [1,]    1    0    1    0    0    0    0    0    0     0     0     0     0     0
      [2,]    1    0    1    0    1    0    1    0    1     0     1     0     0     0
      [3,]    1    0    1    0    0    1    0    1    0     0     0     0     0     0
      [4,]    0    0    0    0    0    0    0    0    0     0     0     0     0     0
           [,15] [,16] [,17] [,18] [,19] [,20] [,21]
      [1,]     0     0     0     0     0     0     0
      [2,]     0     1     0     0     0     0     0
      [3,]     1     0     0     0     0     0     0
      [4,]     0     0     0     0     0     0     0
